pm4py.algo.discovery.ocel.link\_analysis.variants package
=========================================================

Submodules
----------

pm4py.algo.discovery.ocel.link\_analysis.variants.classic module
----------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.ocel.link_analysis.variants.classic
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.ocel.link_analysis.variants
   :members:
   :undoc-members:
   :show-inheritance:
